@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2005
+ * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2005,
+ *	2010
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -196,21 +196,15 @@ makedefineindex(const char *file, int total, STRBUF *defines)
 
 		if (line == NULL)
 			die("internal error in makedefineindex()."); 
+		/*
+		 * About the format of 'line', please see the head comment of cache.c.
+		 */
 		if (*line == ' ') {
-			SPLIT ptable;
-			const char *fid, *enumber;
+			const char *fid = line + 1;
+			const char *enumber = nextstring(fid);
 
-			if (split((char *)line + 1, 2, &ptable) < 2) {
-				recover(&ptable);
-				die("too small number of parts in makedefineindex().\n'%s'", line);
-			}
-			fid     = ptable.part[0].start;
-			enumber = ptable.part[1].start;
 			snprintf(url_for_map, sizeof(url_for_map), "%s/%s.%s",
 				DEFS, fid, HTML);
-			/*
-			 * cache record: " <file id> <entry number>"
-			 */
 			if (dynamic) {
 				if (*action != '/' && aflag)
 					strbuf_puts(url, "../");
@@ -222,27 +216,18 @@ makedefineindex(const char *file, int total, STRBUF *defines)
 				strbuf_sprintf(url, "%s/%s.%s", DEFS, fid, HTML);
 			}
 			snprintf(guide, sizeof(guide), "Multiple defined in %s places.", enumber);
-			recover(&ptable);
 		} else {
-			SPLIT ptable;
-			const char *lno, *fid, *path;
+			const char *lno = line;
+			const char *fid = nextstring(line);
+			const char *path = gpath_fid2path(fid, NULL);
 
-			if (split((char *)line, 2, &ptable) < 2) {
-				recover(&ptable);
-				die("too small number of parts in makedefineindex().\n'%s'", line);
-			}
-			lno = ptable.part[0].start;
-			path = ptable.part[1].start;
 			path += 2;		/* remove './' */
-
-			fid = path2fid(path);
 			snprintf(url_for_map, sizeof(url_for_map), "%s/%s.%s#L%s",
 				SRCS, fid, HTML, lno);
 			if (aflag)
 				strbuf_puts(url, "../");
 			strbuf_sprintf(url, "%s/%s.%s#L%s", SRCS, fid, HTML, lno);
 			snprintf(guide, sizeof(guide), "Defined at %s in %s.", lno, path);
-			recover(&ptable);
 		}
 		if (!no_order_list)
 			fputs(item_begin, STDOUT);
